#region Using declarations
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.ComponentModel.DataAnnotations;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Input;
using System.Windows.Media;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Gui;
using NinjaTrader.Gui.Chart;
using NinjaTrader.Gui.SuperDom;
using NinjaTrader.Data;
using NinjaTrader.NinjaScript;
using NinjaTrader.Core.FloatingPoint;
using NinjaTrader.NinjaScript.DrawingTools;
using SharpDX;
using SharpDX.Direct2D1;

#endregion

namespace NinjaTrader.NinjaScript.Indicators {

	public class TrendLineOne : Indicator {
		
		public struct Point {
			public int x;
			public double y;
		}
		
		// y = mx + n
		public struct Line {
			public Point p1;
			public Point p2;
			public Point pb;
			public double m;
			public double n;
		}
		
		private Line Resistance = new Line();
		private Line Support = new Line();
					
		protected override void OnStateChange() {
			
			if (State == State.SetDefaults)	{
				
				Description					= "TrendLineOne";
				Name						= "TrendLineOne";
				IsAutoScale					= false;
				IsOverlay					= true;
				IsSuspendedWhileInactive	= true;
				
				HighNum						= 10;
				LowNum						= 10;

				AddPlot( Brushes.Red, "Resistance" );
				AddPlot( Brushes.Green, "Support" );
				AddPlot( Brushes.Blue, "Resistance_Broken" );
				AddPlot( Brushes.Blue, "Support_Broken" );
				AddPlot( Brushes.Blue, "Resistance_Slope" );
				AddPlot( Brushes.Blue, "Support_Slope" );
				
			} else if (State == State.DataLoaded) {
				
				Resistance.p1.x = 0;
				Resistance.p2.x = 0;
				Resistance.pb.x = 0;

				Support.p1.x = 0;
				Support.p2.x = 0;
				Support.pb.x = 0;
			}
		}

		/* 
		Es werden eine aktuelle Widerstandslinie oberhalb des Kursverlaufes, sowie eine
		Unterstützungslinie unterhalb des Kursverlaufes gesucht.
		
		Für die Widerstandslinie werden zwei Punkte (H1 und H2) im Chart ermittelt, durch 
		die einie Linie gezeichnet wird. Jeder dieser Punkte hat einen X und einen Y Wert. 
		X ist die Nummer der Kerze (CurrentBar) und Y ist der Kurswert. 
		Die Punkte werden aus allen	Hochkursen der Kerzen gesucht.
		Ein Hochkurs kommt als Widerstandslinienpunkt in Frage, wenn ausreichend viele
		Hochkurse davor und danach kleiner sind. */
		protected override void OnBarUpdate() {
			
			Text t;
			
			// wenn ausreichend Kerzen vorhanden sind UND
			// wenn das Hoch vor HighNum Kerzen ein Maximum im Bereich davor und dahinter war
			if ( CurrentBar > 2*HighNum+1 && High[HighNum] == MAX( High, 2*HighNum+1 )[0] ) {
				
				// der X Wert von H2
				int new_x_h2 = CurrentBar - HighNum;
				
				// liegt H2 ausreichend weit weg vom alten H2 (der dann ja H1 werden würde)
				if ( new_x_h2 - Resistance.p2.x > HighNum  ) {
					
					// aus H2 wird H1
					Resistance.p1.x = Resistance.p2.x;
					Resistance.p1.y = Resistance.p2.y;
					
					// der neue Punkt H2
					Resistance.p2.x = new_x_h2;
					Resistance.p2.y = High[HighNum];
					
					// Bruch der Linie zurücksetzen
					Resistance.pb.x = 0;
					Resistance.pb.y = 0.0;
					RemoveDrawObject( "Punkt Bruch Widerstand" );

					t = Draw.Text( this, "H1", Resistance.p1.y + "\nH1", CurrentBar-Resistance.p1.x, Resistance.p1.y );
					t.YPixelOffset = 20;
					Draw.Dot( this, "Punkt H1", true, CurrentBar-Resistance.p1.x, Resistance.p1.y, Plots[0].Brush );
					
					t = Draw.Text( this, "H2", Resistance.p2.y + "\nH2", CurrentBar-Resistance.p2.x, Resistance.p2.y );
					t.YPixelOffset = 20;
					Draw.Dot( this, "Punkt H2", true, CurrentBar-Resistance.p2.x, Resistance.p2.y, Plots[0].Brush );
				}
			}
			
			// wurde inzwischen ein H1 und ein H2 gefunden?
			if ( Resistance.p1.x > 0 && Resistance.p2.x > 0 ) {
				
				// Geradengleichung
				// y = mx + n
				Resistance.m = ( Resistance.p2.y - Resistance.p1.y ) / ( Resistance.p2.x - Resistance.p1.x );
				Resistance.n = Resistance.p1.y - Resistance.m * Resistance.p1.x;
				
				Resistance_Value[0] = Resistance.m * CurrentBar + Resistance.n;
				Resistance_Slope[0] = Resistance.m;
				
				if ( Resistance.pb.x == 0 ) {
					// Prüfung, ob Linie gebrochen wurde
					if ( Close[0] > Resistance.m * CurrentBar + Resistance.n ) {
						Draw.Dot( this, "Punkt Bruch Widerstand", true, 0, Resistance.m * CurrentBar + Resistance.n, Plots[0].Brush );
						Resistance.pb.x = CurrentBar;
						Resistance.pb.y = Resistance.m * CurrentBar + Resistance.n;
						Draw.Line( this, "R " + CurrentBar, CurrentBar-Resistance.p1.x, Resistance.p1.y, CurrentBar-Resistance.pb.x, Resistance.pb.y, Plots[0].Brush );
					}
				}
			}
			
			Resistance_Broken[0] = Resistance.pb.x > 0 ? 1.0 : 0.0;

			if ( CurrentBar > 2*LowNum+1 && Low[LowNum] == MIN( Low, 2*LowNum+1 )[0] ) {
				
				int new_x_l2 = CurrentBar - LowNum;
				
				if ( new_x_l2 - Support.p2.x > LowNum  ) {
					
					Support.p1.x = Support.p2.x;
					Support.p1.y = Support.p2.y;
					
					Support.p2.x = new_x_l2;
					Support.p2.y = Low[LowNum];
										
					
					Support.pb.x = 0;
					Support.pb.y = 0.0;
					RemoveDrawObject( "Punkt Bruch Unterstützung" );
					
					t = Draw.Text( this, "L1", "L1\n" + Support.p1.y, CurrentBar-Support.p1.x, Support.p1.y );
					t.YPixelOffset = -20;
					Draw.Dot( this, "Punkt L1", true, CurrentBar-Support.p1.x, Support.p1.y, Plots[1].Brush );
					
					t = Draw.Text( this, "L2", "L2\n" + Support.p2.y, CurrentBar-Support.p2.x, Support.p2.y );
					t.YPixelOffset = -20;
					Draw.Dot( this, "Punkt L2", true, CurrentBar-Support.p2.x, Support.p2.y, Plots[1].Brush );
				}
			}
			
			if ( Support.p1.x > 0 && Support.p2.x > 0 ) {
				
				Support.m = ( Support.p2.y - Support.p1.y ) / ( Support.p2.x - Support.p1.x );
				Support.n = Support.p1.y - Support.m * Support.p1.x;
				
				Support_Value[0] = Support.m * CurrentBar + Support.n;
				Support_Slope[0] = Support.m;
				
				if ( Support.pb.x == 0 ) {
					// Prüfung, ob Linie gebrochen wurde
					if ( Close[0] < Support.m * CurrentBar + Support.n ) {
						Draw.Dot( this, "Punkt Bruch Unterstützung", true, 0, Support.m * CurrentBar + Support.n, Plots[1].Brush );
						Support.pb.x = CurrentBar;
						Support.pb.y = Support.m * CurrentBar + Support.n;
						Draw.Line( this, "S " + CurrentBar, CurrentBar-Support.p1.x, Support.p1.y, CurrentBar-Support.pb.x, Support.pb.y, Plots[1].Brush );
					}
				}
			}
			
			Support_Broken[0] = Support.pb.x > 0 ? 1.0 : 0.0;
			
			
			// Potentieller Hochpunkt
			/* if ( State == State.Realtime && Resistance.p1.x > 0 && Resistance.p2.x > 0 ) {
				
				int start = Resistance.p2.x + HighNum + 1;

				bool is_high = true;
				for ( int i=start-HighNum; i<=start+HighNum; i++ ) {
					if ( High[i] > High[start] ) {
						is_high = false;
					}
				}
				
				if ( is_high ) {
					Print( start );
					Draw.Dot( this, "Punkt H?", true, start, High[start], Brushes.Gray );
				}
			} */
			
		}

		protected override void OnRender( ChartControl chartControl, ChartScale chartScale ) {
			
			Vector2 v_h1 = new Vector2( ChartControl.GetXByBarIndex( ChartBars, Resistance.p1.x ), chartScale.GetYByValue( Resistance.p1.y ) );
			Vector2 v_h2 = new Vector2( ChartControl.GetXByBarIndex( ChartBars, Resistance.pb.x ), chartScale.GetYByValue( Resistance.pb.y ) );
			Vector2 v_h3 = new Vector2( ChartControl.GetXByBarIndex( ChartBars, CurrentBar+10 ), chartScale.GetYByValue( Resistance.m * (CurrentBar+10) + Resistance.n ) );

			Vector2 v_l1 = new Vector2( ChartControl.GetXByBarIndex( ChartBars, Support.p1.x ), chartScale.GetYByValue( Support.p1.y ) );
			Vector2 v_l2 = new Vector2( ChartControl.GetXByBarIndex( ChartBars, Support.pb.x ), chartScale.GetYByValue( Support.pb.y ) );
			Vector2 v_l3 = new Vector2( ChartControl.GetXByBarIndex( ChartBars, CurrentBar+10 ), chartScale.GetYByValue( Support.m * (CurrentBar+10) + Support.n ) );
		
			RenderTarget.AntialiasMode = AntialiasMode.PerPrimitive;
			
			if ( Resistance.pb.x > 0 ) {
				RenderTarget.DrawLine( v_h1, v_h2, Plots[0].BrushDX, Plots[0].Width+1, Plots[0].StrokeStyle );
				RenderTarget.DrawLine( v_h2, v_h3, Plots[0].BrushDX, Plots[0].Width, Plots[0].StrokeStyle );
			} else {
				RenderTarget.DrawLine( v_h1, v_h3, Plots[0].BrushDX, Plots[0].Width+1, Plots[0].StrokeStyle );
			}
			
			if ( Support.pb.x > 0 ) {
				RenderTarget.DrawLine( v_l1, v_l2, Plots[1].BrushDX, Plots[1].Width+1, Plots[1].StrokeStyle );
				RenderTarget.DrawLine( v_l2, v_l3, Plots[1].BrushDX, Plots[1].Width, Plots[1].StrokeStyle );
			} else {
				RenderTarget.DrawLine( v_l1, v_l3, Plots[1].BrushDX, Plots[1].Width+1, Plots[1].StrokeStyle );
			}
			
			RenderTarget.AntialiasMode = AntialiasMode.Aliased;
		}
		
		#region Properties
		[Browsable(false)]
		[XmlIgnore()]
		public Series<double> Resistance_Value { get { return Values[0]; }	}

		[Browsable(false)]
		[XmlIgnore()]
		public Series<double> Support_Value { get { return Values[1]; } }
		
		[Browsable(false)]
		[XmlIgnore()]
		public Series<double> Resistance_Broken { get { return Values[2]; } }

		[Browsable(false)]
		[XmlIgnore()]
		public Series<double> Support_Broken { get { return Values[3]; } }

		[Browsable(false)]
		[XmlIgnore()]
		public Series<double> Resistance_Slope { get { return Values[4]; } }
		
		[Browsable(false)]
		[XmlIgnore()]
		public Series<double> Support_Slope { get { return Values[5]; } }


		[Range(1, int.MaxValue), NinjaScriptProperty]
		[Display(ResourceType = typeof(Custom.Resource), Name = "Abstand Hoch", GroupName = "NinjaScriptGeneral", Order = 0)]
		public int HighNum
		{ get; set; }

		[Range(1, int.MaxValue), NinjaScriptProperty]
		[Display(ResourceType = typeof(Custom.Resource), Name = "Abstand Tief", GroupName = "NinjaScriptGeneral", Order = 1)]
		public int LowNum
		{ get; set; }
		#endregion
	}
}

#region NinjaScript generated code. Neither change nor remove.

namespace NinjaTrader.NinjaScript.Indicators
{
	public partial class Indicator : NinjaTrader.Gui.NinjaScript.IndicatorRenderBase
	{
		private TrendLineOne[] cacheTrendLineOne;
		public TrendLineOne TrendLineOne(int highNum, int lowNum)
		{
			return TrendLineOne(Input, highNum, lowNum);
		}

		public TrendLineOne TrendLineOne(ISeries<double> input, int highNum, int lowNum)
		{
			if (cacheTrendLineOne != null)
				for (int idx = 0; idx < cacheTrendLineOne.Length; idx++)
					if (cacheTrendLineOne[idx] != null && cacheTrendLineOne[idx].HighNum == highNum && cacheTrendLineOne[idx].LowNum == lowNum && cacheTrendLineOne[idx].EqualsInput(input))
						return cacheTrendLineOne[idx];
			return CacheIndicator<TrendLineOne>(new TrendLineOne(){ HighNum = highNum, LowNum = lowNum }, input, ref cacheTrendLineOne);
		}
	}
}

namespace NinjaTrader.NinjaScript.MarketAnalyzerColumns
{
	public partial class MarketAnalyzerColumn : MarketAnalyzerColumnBase
	{
		public Indicators.TrendLineOne TrendLineOne(int highNum, int lowNum)
		{
			return indicator.TrendLineOne(Input, highNum, lowNum);
		}

		public Indicators.TrendLineOne TrendLineOne(ISeries<double> input , int highNum, int lowNum)
		{
			return indicator.TrendLineOne(input, highNum, lowNum);
		}
	}
}

namespace NinjaTrader.NinjaScript.Strategies
{
	public partial class Strategy : NinjaTrader.Gui.NinjaScript.StrategyRenderBase
	{
		public Indicators.TrendLineOne TrendLineOne(int highNum, int lowNum)
		{
			return indicator.TrendLineOne(Input, highNum, lowNum);
		}

		public Indicators.TrendLineOne TrendLineOne(ISeries<double> input , int highNum, int lowNum)
		{
			return indicator.TrendLineOne(input, highNum, lowNum);
		}
	}
}

#endregion
